{% block html %}
<div id="back-top"></div>
{% endblock %}

{% block js %}
    <script>
        jQuery(function ($) {
            var o = $("#back-top");
            o.hide();
            $(function () {
                $(window).scroll(function () {
                    if ($(this).scrollTop() > {{ position|default:100 }}) {
                        o.fadeIn();
                    } else {
                        o.fadeOut();
                    }
                });
                o.click(function () {
                    $('body, html').animate({
                        scrollTop:0
                    }, 800);
                    return false;
                });
            });
        });
    </script>
{% endblock %}