{% load social %}
<div class="twitter">
    <div class="header">Tweets of {{ name }}</div>
    <ol>
        {% for tweet in tweets %}
            <li class="tweet h-entry" data-tweet-id="{{ tweet.id_str }}">
                <a class="u-url permalink customisable-highlight"
                   href="https://twitter.com/ajumell/statuses/{{ tweet.id_str }}"
                   data-datetime="{{ tweet.created_at }}">
                    <time class="dt-updated" datetime="{{ tweet.created_at }}"
                          title="Time posted: {{ tweet.created_at }}">
                        {{ tweet.created_at }}
                    </time>
                </a>

                <div class="header h-card p-author">
                    <a class="u-url profile" href="https://twitter.com/{{ tweet.author.screen_name }}" aria-label="{{ tweet.author.name }} (screen name: {{ tweet.author.screen_name }})">
                        <img class="u-photo avatar" alt="" src="{{ tweet.author.profile_image_url }}" width="48" height="48" />
                        <span class="full-name">
                          <span class="p-name customisable-highlight">{{ tweet.author.name }}</span>
                        </span>
                        <span class="p-nickname" dir="ltr">@<b>{{ tweet.author.screen_name }}</b></span>
                    </a>
                </div>

                <div class="e-entry-content">
                    <p class="e-entry-title">
                        {{ tweet.text|format_tweet }}
                    </p>
                    <div class="detail-expander">
                        <div class="detail-content" data-expanded-media=""></div>
                    </div>
                </div>

            </li>
        {% endfor %}
    </ol>
</div>
