<iframe src="http://www.facebook.com/plugins/like.php?href={{ url }}&amp;send=false&amp;layout=box_count&amp;width={{ width|default:450 }}&amp;show_faces=true&amp;action=like&amp;colorscheme={{ scheme|default:"light" }}&amp;font={{ font|default:"tahoma" }}&amp;height={{ height|default:90 }}"
        scrolling="no" frameborder="0" style="border:none; overflow:hidden; width:{{ width|default:450 }}px; height:{{ height|default:90 }}px;" allowTransparency="true"></iframe>